Package: NTW
Type: Package
Title: Predict gene network using an Ordinary Differential Equation
        (ODE) based method
Depends: R (>= 2.3.0)
Imports: mvtnorm, stats, utils
Version: 1.63.0
Date: 2011-10-8
Author: Wei Xiao, Yin Jin, Darong Lai, Xinyi Yang, Yuanhua Liu, Christine Nardini
Maintainer: Yuanhua Liu <liuyuanhua@picb.ac.cn>
Description: This package predicts the gene-gene interaction network and identifies the direct transcriptional targets of the perturbation using an ODE (Ordinary Differential Equation) based method.  
License: GPL-2
biocViews: Preprocessing
LazyLoad: yes
git_url: https://git.bioconductor.org/packages/NTW
git_branch: devel
git_last_commit: 5e5ce31
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.24
Date/Publication: 2026-04-28
NeedsCompilation: no
Packaged: 2026-04-29 00:06:36 UTC; biocbuild
